[gnus git] branch master updated: n0-17-151-ge44b0fd =3= * gnus.texi (Subscription Methods): Link to "Group Levels" to explain zombies. ; * gnus.el (gnus-summary-line-format): Link to the info node for %U instead of trying to list them all (bug#8978). ; * gnus.texi (Startup Files): Clarify that we're talking about numbered backups, and not actual vc (bug#8975).

Lars Magne Ingebrigtsen <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  e44b0fdc508944e564941bb6f29a59c549bff7bd (commit)
       via  e26fef5439c37ebee6e26f65a339c8b32c02ebf7 (commit)
       via  877e878b0214961c69a4ad155a8efe12f54714af (commit)
      from  0423b87a0e0f8d3de7ddd308fbfb42ae1ddad960 (commit)


- Log -----------------------------------------------------------------
commit e44b0fdc508944e564941bb6f29a59c549bff7bd
Author: Lars Magne Ingebrigtsen <[email protected]>
Date:   Sun Jul 3 18:29:34 2011 +0200

    * gnus.texi (Subscription Methods): Link to "Group Levels" to explain zombies.

diff --git a/texi/ChangeLog b/texi/ChangeLog
index 439c7f7..f305d39 100644
--- a/texi/ChangeLog
+++ b/texi/ChangeLog
@@ -1,3 +1,8 @@
+2011-07-03  Lars Magne Ingebrigtsen  <[email protected]>
+
+	* gnus.texi (Subscription Methods): Link to "Group Levels" to explain
+	zombies.
+
 2011-07-03  Dave Abrahams  <[email protected]>  (tiny change)
 
 	* gnus.texi (Startup Files): Clarify that we're talking about numbered
diff --git a/texi/gnus.texi b/texi/gnus.texi
index b1b132e..517b609 100644
--- a/texi/gnus.texi
+++ b/texi/gnus.texi
@@ -1214,9 +1214,10 @@ Some handy pre-fab functions are:
 
 @item gnus-subscribe-zombies
 @vindex gnus-subscribe-zombies
-Make all new groups zombies.  This is the default.  You can browse the
-zombies later (with @kbd{A z}) and either kill them all off properly
-(with @kbd{S z}), or subscribe to them (with @kbd{u}).
+Make all new groups zombies (@pxref {Group Levels}).  This is the
+default.  You can browse the zombies later (with @kbd{A z}) and either
+kill them all off properly (with @kbd{S z}), or subscribe to them
+(with @kbd{u}).
 
 @item gnus-subscribe-randomly
 @vindex gnus-subscribe-randomly
@@ -2360,6 +2361,7 @@ empty subscribed groups and unsubscribed groups, too.  Type @kbd{l} to
 go back to showing nonempty subscribed groups again.  Thus, unsubscribed
 groups are hidden, in a way.
 
+@cindex zombie groups
 Zombie and killed groups are similar to unsubscribed groups in that they
 are hidden by default.  But they are different from subscribed and
 unsubscribed groups in that Gnus doesn't ask the news server for

commit e26fef5439c37ebee6e26f65a339c8b32c02ebf7
Author: Lars Magne Ingebrigtsen <[email protected]>
Date:   Sun Jul 3 18:24:16 2011 +0200

    * gnus.el (gnus-summary-line-format): Link to the info node for %U
    instead of trying to list them all (bug#8978).

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 7255d9b..5b34127 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,8 @@
+2011-07-03  Lars Magne Ingebrigtsen  <[email protected]>
+
+	* gnus.el (gnus-summary-line-format): Link to the info node for %U
+	instead of trying to list them all (bug#8978).
+
 2011-07-03  Wolfgang Jenkner  <[email protected]>  (tiny change)
 
 	* pop3.el (pop3-open-server): Use :end-of-capability.
diff --git a/texi/ChangeLog b/texi/ChangeLog
index 295dcd4..439c7f7 100644
--- a/texi/ChangeLog
+++ b/texi/ChangeLog
@@ -1,3 +1,8 @@
+2011-07-03  Dave Abrahams  <[email protected]>  (tiny change)
+
+	* gnus.texi (Startup Files): Clarify that we're talking about numbered
+	backups, and not actual vc (bug#8975).
+
 2011-06-26  Lars Magne Ingebrigtsen  <[email protected]>
 
 	* gnus.texi (Summary Mail Commands): Document
diff --git a/texi/gnus.texi b/texi/gnus.texi
index 8350be7..b1b132e 100644
--- a/texi/gnus.texi
+++ b/texi/gnus.texi
@@ -1430,7 +1430,7 @@ several servers where not all servers support @code{ask-server}.
 The @code{gnus-startup-file} variable says where the startup files are.
 The default value is @file{~/.newsrc}, with the Gnus (El Dingo) startup
 file being whatever that one is, with a @samp{.eld} appended.
-If you want version control for this file, set
+If you want to keep multiple numbered backups of this file, set
 @code{gnus-backup-startup-file}.  It respects the same values as the
 @code{version-control} variable.
 

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog |    5 +++++
 lisp/gnus.el   |    4 ++--
 texi/ChangeLog |   10 ++++++++++
 texi/gnus.texi |   10 ++++++----
 4 files changed, 23 insertions(+), 6 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
diff --git a/lisp/gnus.el b/lisp/gnus.el
index 88eccbf..93ee375 100644
--- a/lisp/gnus.el
+++ b/lisp/gnus.el
@@ -2965,8 +2965,8 @@ with some simple extensions.
             on level one
 %R          \"A\" if this article has been replied to, \" \"
             otherwise (character)
-%U          Status of this article (character, \"R\", \"K\",
-            \"-\" or \" \")
+%U          \"Read\" status of this article.
+            See Info node `(gnus)Read Articles'
 %[          Opening bracket (character, \"[\" or \"<\")
 %]          Closing bracket (character, \"]\" or \">\")
 %>          Spaces of length thread-level (string)

commit 877e878b0214961c69a4ad155a8efe12f54714af
Author: Dave Abrahams <[email protected]>
Date:   Sun Jul 3 18:18:15 2011 +0200

    * gnus.texi (Startup Files): Clarify that we're talking about numbered
    backups, and not actual vc (bug#8975).

-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.